@@ -468,6 +468,13 @@ def predict_orfs(config, contigs, filteredDraftGenomePath):
         '-f', 'gff',  # GFF output
         '-o', str(gff_path)  # prodigal output
     ]
+
+    genome_size = sum([v['length'] for k, v in contigs.items()])
+    if(config['args']['characterize'] and genome_size < 50000):
+        cmd.append('-p')
+        cmd.append('meta')
+        log.info('ORFs: execute prodigal in meta mode! characterize=%s, genome-size=%d', config['args']['characterize'], genome_size)
+
     proc = sp.run(
         cmd,
         cwd=str(config['tmp']),
@@ -484,7 +491,7 @@ def predict_orfs(config, contigs, filteredDraftGenomePath):
             'ORFs: cmd=%s stdout=\'%s\', stderr=\'%s\'',
             cmd, proc.stdout, proc.stderr
         )
-        return
+        return None
 
     # parse orfs
     with gff_path.open() as fh:
@@ -681,13 +688,20 @@ def search_conjugation_genes(config, contigs, filteredProteinsPath):
     return
 
 
-def setup_configuration():
+def setup_configuration(args):
     """Test environment and build a runtime configuration."""
 
     config = {
         'env': os.environ.copy(),
         'tmp': Path(tempfile.mkdtemp()),
-        'bundled-binaries': False
+        'bundled-binaries': False,
+        'args': {
+            'mode': args.mode,
+            'characterize': args.characterize,
+            'threads': args.threads,
+            'output': args.output,
+            'verbose': args.verbose
+        }
     }
     base_dir = Path(__file__).parent.parent
     share_dir = base_dir.joinpath('share')
